@@ -1,13 +1,9 @@
-from .combinations import n_conditions_to_combinations
-from . import Formatter as cc_Formatter
-from .maths import convert_to_int_or_float, rint
 import numpy as np
-import glob
 import math
 import numbers
-import os
-import csv
 import cv2
+from . import maths as cc_maths
+# from .maths import convert_to_int_or_float, rint
 
 
 def advanced_indexing(indexes_loose):
@@ -428,7 +424,7 @@ def split_by_percentages(array, p_samples, axis=0, shuffle=False, sort=False):
     M = np.empty(S, dtype='i')
 
     for s in range(S):
-        M[s] = rint(N / 100 * p_samples[s])
+        M[s] = cc_maths.rint(N / 100 * p_samples[s])
 
     sum_M = M.sum()
     if sum_M != N:
@@ -643,10 +639,10 @@ class Range:
         else:
             raise TypeError('raw_range')
 
-        self.start = convert_to_int_or_float(start)
-        self.stop = convert_to_int_or_float(stop)
-        self.step = convert_to_int_or_float(step)
-        self.len = convert_to_int_or_float((self.stop - self.start) / self.step)
+        self.start = cc_maths.convert_to_int_or_float(start)
+        self.stop = cc_maths.convert_to_int_or_float(stop)
+        self.step = cc_maths.convert_to_int_or_float(step)
+        self.len = cc_maths.convert_to_int_or_float((self.stop - self.start) / self.step)
 
     # def __init__(self, stop, *args):
     #
@@ -666,7 +662,7 @@ class Range:
     #     else:
     #         raise TypeError('MyRange expected at most 3 arguments, got {}'.format(n_args + 1))
     #
-    #     self.len = convert_to_int_or_float((self.stop - self.start) / self.step)
+    #     self.len = cc_maths.convert_to_int_or_float((self.stop - self.start) / self.step)
     #     # self.len = (self.stop - self.start) / self.step
 
     def starts_of_n_within_equal_ranges(self, n):
