@@ -174,8 +174,8 @@ class Loader:
 
         if self.shuffle:
             self.batches_indexes = np.split(np.random.permutation(self.samples_indexes), self.n_batches, axis=0)
-        for b in range(3):
-        # for b in range(self.n_batches):
+        # for b in range(3):
+        for b in range(self.n_batches):
             labels_b = self.labels[self.batches_indexes[b]]
             # batch_size_eb = batches_indexes_e.shape[0]
             for i in range(self.batch_size):
