@@ -16,25 +16,16 @@ def initiate(names_submodules_raw=None):
     for name_m in names_submodules:
 
         if name_m == 'descriptive':
-            try:
-                descriptive
-            except NameError:
-                from . import descriptive
-                globals().update(descriptive=descriptive)
+            from . import descriptive
+            globals().update(descriptive=descriptive)
 
         elif name_m == 'paired_t_test':
-            try:
-                paired_t_test
-            except NameError:
-                from . import paired_t_test
-                globals().update(paired_t_test=paired_t_test)
+            from . import paired_t_test
+            globals().update(paired_t_test=paired_t_test)
 
         elif name_m == 'unpaired_t_test':
-            try:
-                unpaired_t_test
-            except NameError:
-                from . import unpaired_t_test
-                globals().update(unpaired_t_test=unpaired_t_test)
+            from . import unpaired_t_test
+            globals().update(unpaired_t_test=unpaired_t_test)
 
         else:
             raise ValueError('Unknown submodule "{}"'.format(name_m))
