@@ -16,10 +16,8 @@ def initiate(names_submodules_raw=None):
     for name_m in names_submodules:
 
         if name_m == 'display':
-            try:
-                display
-            except NameError:
-                from . import display
-                globals().update(display=display)
+            from . import display
+            globals().update(display=display)
+
         else:
             raise ValueError('Unknown submodule "{}"'.format(name_m))
